@@ -23,6 +23,7 @@ bitflags! {
         const ID = 1 << 1;
         const PERMISSIONS = 1 << 2;
         const TIME = 1 << 3;
+        const EXTENSIONS = 1 << 4;
     }
 }
 impl Serialize for FileAttrsFlags {
@@ -55,8 +56,8 @@ impl<'de> crate::visitor::Deserialize<'de> for FileAttrsFlags {
         deserializer: D,
     ) -> Result<Self, D::Error> {
         use constants::{
-            SSH_FILEXFER_ATTR_ACMODTIME, SSH_FILEXFER_ATTR_PERMISSIONS, SSH_FILEXFER_ATTR_SIZE,
-            SSH_FILEXFER_ATTR_UIDGID,
+            SSH_FILEXFER_ATTR_ACMODTIME, SSH_FILEXFER_ATTR_EXTENDED, SSH_FILEXFER_ATTR_PERMISSIONS,
+            SSH_FILEXFER_ATTR_SIZE, SSH_FILEXFER_ATTR_UIDGID,
         };
 
         let flags = u32::deserialize(deserializer)?;
@@ -76,6 +77,9 @@ impl<'de> crate::visitor::Deserialize<'de> for FileAttrsFlags {
         if has_attr(SSH_FILEXFER_ATTR_ACMODTIME) {
             file_attrs_flags |= FileAttrsFlags::TIME;
         }
+        if has_attr(SSH_FILEXFER_ATTR_EXTENDED) {
+            file_attrs_flags |= FileAttrsFlags::EXTENSIONS;
+        }
 
         Ok(file_attrs_flags)
     }
@@ -329,12 +333,7 @@ impl_visitor!(FileAttrs, FileAttrVisitor, "File attributes", seq, {
     }
     if attrs.has_attr(FileAttrsFlags::PERMISSIONS) {
         let raw_perm: u32 = iter.get_next()?;
-        attrs.permissions = Permissions::from_bits(raw_perm).ok_or_else(|| {
-            V::Error::invalid_value(
-                Unexpected::Unsigned(raw_perm as u64),
-                &"Invalid permission: Does not confirm to value specified in POSIX",
-            )
-        })?;
+        attrs.permissions = Permissions::from_bits_truncate(raw_perm);
     }
 
     let into_timestamp = |elapsed: u32| {
@@ -353,6 +352,16 @@ impl_visitor!(FileAttrs, FileAttrVisitor, "File attributes", seq, {
         attrs.mtime = into_timestamp(iter.get_next()?)?;
     }
 
+    if attrs.has_attr(FileAttrsFlags::EXTENSIONS) {
+        let extension_pairs: u32 = iter.get_next()?;
+        for _i in 0..extension_pairs {
+            let _name: &[u8] = iter.get_next()?;
+            let _value: &[u8] = iter.get_next()?;
+        }
+    }
+
+    attrs.flags.remove(FileAttrsFlags::EXTENSIONS);
+
     Ok(attrs)
 });
 
@@ -485,16 +494,6 @@ mod tests {
             &FileAttrsFlags::TIME,
             &[Token::U32(SSH_FILEXFER_ATTR_ACMODTIME)],
         );
-
-        assert_tokens(
-            &FileAttrsFlags::all(),
-            &[Token::U32(
-                SSH_FILEXFER_ATTR_SIZE
-                    | SSH_FILEXFER_ATTR_UIDGID
-                    | SSH_FILEXFER_ATTR_PERMISSIONS
-                    | SSH_FILEXFER_ATTR_ACMODTIME,
-            )],
-        );
     }
 
     fn init_attrs(f: impl FnOnce(&mut FileAttrs)) -> FileAttrs {
